@@ -12,25 +12,28 @@ License: MIT (see LICENSE for details)
 from __future__ import with_statement
 
 __author__ = 'Marcin Wierzbanowski'
-__version__ = '0.9.0'
+__version__ = '0.9.1'
 __license__ = 'MIT'
 
-class JsObject(object):
+
+class Object(object):
+    """ This is a base class """
+
     def __init__(self, data):
-        for k, v in self.__get(data).iteritems():
+        for k, v in self.__get(data).items():
             self.__dict__[k] = self.__set(v)
 
     def __setattr__(self, k, v):
-        self.__dict__[k] = JsObject(v) if type(v) == dict else v
+        self.__dict__[k] = Object(v) if type(v) == dict else v
 
     def __dump(self):
-        return {k: self.__get(v) for k, v in self.__dict__.iteritems()}
+            return dict((k, self.__get(v)) for (k, v) in self.__dict__.items())
 
     def __get(self, v):
-        return v.__dump() if type(v) == JsObject else v
+        return v.__dump() if type(v) == Object else v
 
     def __set(self, v):
-        return JsObject(v) if type(v) == dict else v
+        return Object(v) if type(v) == dict else v
 
     def __str__(self):
         return str(self.__dump())
@@ -47,6 +50,9 @@ class JsObject(object):
     def __len__(self):
         return len(self.__dict__)
 
+    def __getitem__(self, k):
+        return self.__dict__[k]
+"""
 if __name__ == "__main__":
 
     def d(data):
@@ -75,8 +81,9 @@ if __name__ == "__main__":
       "string": "Hello World"
     }
 
-    js = JsObject(data)
-    js2 = JsObject(js)
+    js = Object(data)
+    js2 = Object(js)
+    # js3 = Object([1,2,3])
 
     js.name = 5
     js.nameDict = {}
@@ -84,6 +91,7 @@ if __name__ == "__main__":
     js.nameDict3 = {"objectC": {"a": "A", "b":"B"}}
 
     print js.name == 5
+    print js['name'] == 5
     print js.nameDict
     print js.nameDict2
     print js.nameDict3
@@ -112,7 +120,7 @@ if __name__ == "__main__":
     print "string" in js
     print len(js)
 
-    c = JsObject(data)
+    c = Object(data)
 
     print "--- 0 ------"
     print c.string
@@ -176,3 +184,4 @@ if __name__ == "__main__":
     print c.objectB.a.c
 
     print "---- 11 -----"
+"""
